Sainte Messe Solennelle Gallicane Antique
de Clovis notre Roi Très Chrétien et des Wisigoths
Rite des Gaules de la Sainte Messe du Siège Primatial de Lyon
+Ce Missel est Dédié à la Mémoire
du Patriarche de
l’Eglise Gallicane de Provence Feu Roger Caro - Pierre Phoebus. Qui
avait
retrouvé dans sa Bibliothèque la Messe de Clovis et des Wisigoths dans ce le
livre : La Messe ancienne
comme elle estoit célébrée au temps de
Clovis Nostre I. roy
chrestien
Par le Père François Veron+
+RITE DE l’EGLISE CATHOLIQUE DE RITE GALLICAN+
-HABILLEMENT DU CLERGÉ
-P:
-Lavement des mains
:Donne, Seigneur, à mes mains la
vertu d'effacer toute souillure; purifie mon âme et mon corps par le
sang de
ton Agneau, afin qu'après avoir été lavé, je puisse partager tes joies
éternelles. Amen
-En
prenant chaque ornement, le prêtre le bénit et l’embrasse : -La SOUTANE
(et Clergy Man) :Le
Seigneur est la part de mon Héritage et de mon
Calice, c’est vous Seigneur qui me rendez mon
Héritage. Amen
-SUR L'AMICT :Ton joug est doux et ton fardeau léger;
couvre-moi, Seigneur, du casque du salut.Amen
-SUR
L'AUBE :Le Seigneur m'a revêtu du vêtement du
salut, Il m'a enveloppé d'une tunique de joie, Il m'a orné de beauté.
Amen
-SUR
L'ÉTOLE (Elle peut se porter par dessus le
chasuble
gothique elle mémoire de l’antique coutume mérovingienne) :Rends-moi, Seigneur, la puissance et la
lumière que j'ai perdues par la prévarication de notre premier père,
Adam, et
que j'ose, malgré mon indignité, approcher de ton Trône et T'offrir les
mystères de la joie éternelle. Amen
-LE CORDON :Maintenant tu te ceins toi-même, mais lorsque
tu seras vieux, un autre te ceindra. Ceins-moi, Seigneur, d'une
ceinture de
pureté et que la chasteté demeure en moi. Amen
-SUR LE MANIPULE (si l'on en porte)
: Ta droite,
Seigneur, s'est couverte de la gloire de ta force, tes mains m'ont créé
et
formé. Amen
-La Dalmatique Couvre-moi, Seigneur, de la
dalmatique de charité, afin que ton amour brûle les profondeurs de mon cœur.Amen
-SUR LA CHASUBLE (Ou la Chape): Couvre-moi,
Seigneur, de la chasuble (de ta Chape) de
charité, afin que ton amour brûle les profondeurs de mon cœur.Amen
-SUR LA CROIX PECTORALE : Si quelqu'un veut venir après Moi,
qu'il renonce à lui-même, qu'il se
charge de sa croix, et qu'il Me suive.
Gloire A Vous O Christ. Amen
-En
revêtant les Gants Épiscopaux : Remettez sur
mes mains, Seigneur, la pureté de l'homme nouveau, descendu du Ciel ;
que, de
même que Jacob, ton bien-aimé, couvrant ses mains de peaux de chèvres
et
offrant à son père la nourriture et la boisson les plus agréables,
obtint la
bénédiction de son père, de même la victime salvatrice offerte par nos
mains
mérite-t-elle la bénédiction de ta grâce. Par Jésus-Christ Notre Seigneur.Amen
— En
prenant l’Anneau épiscopal :En prenant l’anneau de la Sagesse, accordez-moi,
Seigneur de conserver en une inviolable fidélité le Dépôt Sacré qui m’a
été
confié par l’Épouse du Christ, c’est-à-dire l’Église. Par Jésus-Christ
Notre
Seigneur. Amen
-Évêque
:SUR LE
PALLIUM : Tu as trouvé la brebis perdue, Tu l'as placée joyeusement sur
tes épaules,
et Tu l'as ramenée dans la bergerie.Amen
-Évêque:
SUR LA CROIX PECTORALE ET L’ENCOLPION : Si quelqu'un veut venir après Moi, qu'il renonce à
lui-même, qu'il se charge de sa croix,
et qu'il Me suive. Louange A Vous O Christ. Amen
-SUR LA CALOTTE OU
LA BARETTE : Tu
as mis sur ma tête une couronne de pierres précieuses ; je T'ai demandé
la vie
et Tu me l'as donnée. Amen
-Évêque:
SUR LA MITRE : Tu as mis
sur ma tête une couronne de pierres précieuses ; je T'ai demandé la vie
et Tu
me l'as donnée. Amen
-En
arborant la Crosse Épiscopale : O Dieu tout-Puissant et
Miséricordieux qui, de l’Arbre de la Science du Bien et du Mal avez
daigné
faire tailler l’instrument de notre Salut, accordez à ce Signe devenu
celui de
la Vie Eternelle le pouvoir de me protéger des Esprits Impurs. Amen+.
— En allumant les Cierges sur l’Autel : O Dieu tout-Puissant, Lumière Inextinguible,
créateur de toutes Clartés, daignez sanctifier † ces Flammes nouvelles
et
faites que nous puissions, nos Âmes définitivement purifiées, parvenir
à
travers la sombre Nuit de ce Monde jusqu’au Séjour de la Lumière
Éternelle. Par
le Christ Notre Seigneur. Amen
— En allumant le Feu de l’Encensoir :-O Dieu Éternel, Lumière et Feu Inextinguible,
daignez sanctifier † et décupler la puissance de ce nouveau foyer
élémentaire.
Faites en sorte, Seigneur, qu’il soit sur cet autel comme fut pour
votre
serviteur Moïse le Buisson Ardent au Rocher d’Horeb : avec Votre
Révélation, le
signe de Votre Amour. Par le Christ Notre Seigneur. Amen
-En disposant les Nappes de l’Autel - (s’il s’agit d’un
Autel portatif)
« Lévites,
entourez l’Autel du Seigneur notre Dieu, revêtez-le de blanc et célébrez par un chant nouveau
les grandeurs et les merveilles de Dieu. Par le Christ Notre-Seigneur.
Ainsi soit-il ».
— En disposant le Calice et la Patène sur l’Autel :-Dieu Tout-Puissant, Sanctificateur Éternel,
c’est à la gloire de Votre NOM que nous consacrons cet Autel. Daignez
donc,
Seigneur, lui conférer l’abondance de Votre Grâce Sanctifiante et Votre
Céleste
Bénédiction. Que les Saints Anges
de Lumière, tous les Saints du Divin
Royaume des Cieux l’entourent, et que
l’Esprit-Saint l’illumine
de ses divines Clartés.
Par le Christ Notre Seigneur. Ainsi
soit-il
-Avant la Messe du Dimanche, le célébrant à la
Sacristie peut bénir selon la coutume de Saint Charlemagne l’Eau
Bénite, qu’il
utilisera pendant l’Aspersion et et
pendant l’année
liturgique.
-Pour ne pas couper le Rite de la Sainte Messe,
le célébrant fera l’Homélie avant ou après la Messe.
-Prière du Rite Gallican de préparation avant
la Sainte Messe
-P: Je me présente , o mon adorable sauveur ! Devant les Saints
Autels, pour
offrir votre Divin Sacrifice. Daignez o Dieu ! M’en
appliquez tout le fruit que vous souhaitez que
j’en retire , et supléez
aux
dispositions qui me manquent. Disposez mon cœur aux doux effets de
votre bonté,
fixez mes sens, réglez mon esprit, purifiez mon âme, effacez par votre
sang
tous les péchés dont vous voyez que je suis coupable. Oubliez
les tous, O Dieu de miséricorde ! Je les déteste pour l’amour de
Vous,
je vous en demande très humblement pardon, pardonnant moi-même de bon coeur à tous ceux qui auraient pu m’offenser.
Faites O mon
doux Jésus, qu’unissant mes intentions aux Vôtres, je me sacrifie tout
à vous,
comme vous vous sacrifiez entièrement pour moi. Amen
Indication pour suivre la
Messe :
« P-F » signifie « prêtre et fidèle » et
veut dire que la prière ou le chant sont récité ensemble prêtre et
fidèles
inclus, si il y a uniquement « P »
alors seul le prêtre récite ou chante la prière et si il y à
uniquement « F » alors
seul les fidèles chante ou récite la prière.Le signe de la Croix + indique
qu’il faut faire le signe de Croix. le texte
latin est en rouge et la traduction française
en noir. Le mot
‘’Oremus’’ en rouge signifie ‘’Prions’.
-Procession d’entrée on sonne trois fois les
cloches et on déclenche la musique d’orgue ou les chants grégoriens :
-Introit : Antiphona
Ad Praelegendum Louanges Royales et
Trisagion
-P: Signe de Croix : +Christus vincit,Christus regnat,Christus imperat!
Laudate Dominum,
omnes gentes!
laudate eum
omnes
populi! Quoniam confirmata est super nos misericordia ejus,et veritas
Domini manet in aeternum.+ Hágios o
Theós,Sanctus Deus,Hágios Ischyrós.Sanctus
Fortis ,Hágios Athánatos,
eléison himás.Sanctus
Immortalis, miserere nobis.
Gloria Patri, et Filio, et Spiritui Sancto.Sicut
erat in principio
et nunc,et
semper, et in saecula saeculorum.
Amen.
- +Le Christ vainc, le Christ règne, le Christ
gouverne ! Louez le Seigneur, toutes les nations ! Louez-le tous les
peuples !
parce que sa miséricorde s'est fait sentir envers nous et que la
vérité, la
vérité du Seigneur demeure, oui demeure pour l'éternité. +Saint Dieu,
Saint
Fort, Saint Immortel , fais-nous
miséricorde. Gloire
au Père, au Fils et au Saint-Esprit. Comme au commencement, maintenant
et
toujours dans les siècles des siècles Ainsi soit-il.
-À la fin de l'introït le célébrant dit
-P: Pax Vobis (Que la Paix soit avec
vous)
et
l’assemblée répond
-F: Et Cum
Spirituo Tuo.
(Et avec
votre Esprit)
-Rite de l’Aspersion en mémoire du Baptême : Le
Célébrant saisit le goupillon se signe avec et Asperges avec l’eau
bénite Trois
fois l’Autel et le Sanctuaire au Points Cardinaux et Asperge l’Assemblée :
-Au Temps Ordinaire : Asperges Me
-P-F:Asperges me, Domine, hyssopo,
et mundabor : lavabis
me,
et super nivem dealbabor.Miserere
mei, Deus, secundum magnam misericordiam
Tuam.Gloria Patri,
et Filio, et Spiritui
Sancto.Sicut erat in principio et nunc,et
semper, et in saecula saeculorum.
Amen
- Purifiez-moi,
Seigneur, avec l'hysope, et je serai sans tache : lavez-moi, et je deviendraiplus blanc que la neige.Ayez pitié de moi, mon Dieu, dans
Votre grande
miséricorde. Gloire au Père, au Fils et au Saint-Esprit. Comme au
commencement,
maintenant et toujours dans les siècles des siècles.Ainsi soit-il.
-Au Temps Pascal : Vidi Aquam
-P-F: Vidi aquam egrediéntem
de templo, a látere
dextro, allelúia : et omnes
ad quos pervénit
aqua ista, salvi
facti sunt,
et dicent : allelúia,
allelúia.Confitémini Dómino, quóniam
bonus : quóniam in sǽculum
misercórdia eius.Gloria Patri, et Filio,
et Spiritui Sancto.Sicut
erat in principio et nunc,et
semper, et
in saecula saeculorum.
Amen
- J'ai vu l'eau
jaillir du côté droit du Temple, alleluia
; et tous ceux que l'eau a atteints sont sauvés et
ils chantent alleluia, alleluia.Louez le
Seigneur car Il est bon, éternel
est Son amour.Gloire au Père, au Fils et
au
Saint-Esprit. Comme au commencement, maintenant et toujours dans les
siècles
des siècles.Ainsi
soit-il.
-P: Ostende nobis, Domine, misericordiam
tuam. (T.P.
Alleluia)
Montrez-nous, Seigneur,Votre
miséricorde. (TP Alleluia)
- F:
Et salutare tuum
da nobis. (T.P.Alleluia)
Accordez-nous
Votre salut. (TP Alleluia)
- P: Domine exaudi orationem meam
Seigneur, exaucez ma prière.
-F: Et clamor meus
ad te veniat
Que mon cri parvienne jusqu'à Vous.
-P: Dominus vobiscum.
Le
Seigneur soit avec vous.
- F: Et
cum spiritu tuo.
Et avec votre
esprit
-P:Orémus:Exaudi nos, Domine sancte, Pater omnipotens, aeterne
Deus : et mittere digneris
sanctum Angelum
Tuum de caelis,
qui custodiat, foveat,
protegat, visitet,
atque defendat
omnes habitantes in hoc habitaculo.Per Christum
Dominum nostrum. Amen. - Daignez, Seigneur, nous envoyer du Ciel votre
Saint Ange, afin qu'il garde, soutienne, protège, visite et défende vos
fidèles
assemblés en ce Temple. Par Christ
Notre Seigneur. Amen
-Après
l’Asperges Me début des Ordinations – Consécrations – Adoubements -
Bénédictions.
-Prières au bas de l’Autel:
-P-F: In nómine Patris,
et Fílii,
et Spíritus Sancti. Amen
Au nom
du Père, et du Fils, et du Saint Esprit.Amen
-P: Introíbo
ad altáre Dei.
Je m’approcherai de l’autel de
Dieu.
-F: Ad Deum qui laetíficat juventútem meam.
De
Dieu, la joie de ma jeunesse.
-P:Pone, Dómine, custódiam
ori meo.
Placez,
Seigneur, une garde à ma bouche.
-F:Et óstium circumstántiae
lábiis meis.
Une
sentinelle à la porte de mes lèvres.
-P: Confitémini Dómino, quóniam
bonus.
Louez
le Seigneur, car il est bon.
-F: Quóniam
in saéculum misericórdia
ejus.
Et sa
miséricorde est éternelle.
- Confiteor –
Sacrement de l’Absolution :
Le prêtre
invite
d’abord les fidèles à la pénitence en disant:
-P: Frères et Soeurs,Préparons
nous à la célébration du Mystère de l’Eucharistie en
reconnaissant que
nous sommes pécheurs.
-Le prêtre et les
fidèles se confessent ensemble à Dieu
-P-F :Confiteor Deo omnipotenti, beatae Mariae
semper virgini, beato
Michaeli archangelo,
beato Joanni
Baptistae, sanctis
Apostolis
Petro et
Paulo, omnibus Sanctis,et tibi, Pater,quia
peccavi nimis cogitatione,
verbo, et opere :
Les Fidèles et le Prêtre se
tapent
trois fois la poitrine en disant : mea culpa, mea culpa, mea maxima culpa.Ideo
precor beatam
Mariam semper virginem, beatum Michaelem archangelum, beatum
Joannem Baptistam,
sanctos Apostolos
Petrum et Paulum,
omnes Sanctos,
et te, Pater, orare pro me ad Dominum Deum
nostrum. Amen
Je confesse à Dieu tout-puissant, à la Bienheureuse
Marie toujours Vierge, à Saint Michel Archange,à
Saint Jean le Baptiste, aux Saints Apôtres Pierre et Paul, à tous les
Saints,
et à vous, mon Père, parce que j'ai beaucoup péché, en pensée, en
parole, par action.Les Fidèles et le Prêtre se tapent
trois fois la poitrine en
disant : C'est ma faute, c'est
ma faute, c'est ma très grande faute.C'est
pourquoi
je supplie la Bienheureuse Marie toujours Vierge,Saint
Michel Archange, Saint Jean le Baptiste, les Saints Apôtres Pierre et
Paul,
tous les Saints, et vous, mon Père, de prier pour moi le Seigneur notre
Dieu.
Amen
-Le prêtre et les fidèles disent ensemble la
prière pour le pardon-P-F: Qu'il en soit ainsi, Frères, par la puissance
de la Sainte Croix, l’intercession de la Bienheureuse et Glorieuse
Marie
toujours Vierge et les mérites de tous les Saints et Saintes de Dieu.Que le Dieu tout-puissant nous fasse
miséricorde et
pardonne tous nos péchés+++, et que notre Seigneur Jésus-Christ nous
conduise
avec ses saints à la vie éternelle. -P-F
: Amen.
-Puis le prêtre absout les péchés des fidèles
par le Signe de la Croix -P:
Frères
et Sœurs, qui avez fait un acte de contrition sincère en repentir de
vos fautes
recevez la Sainte absolution, afin que vous puissiez recevoir la Sainte
Eucharistie:
Absolutionem+++ et veram remissiónem ómnium peccatórum vestrórum,
per confessiónem, contritiónem,
paenitentiam, et per satisfactiónem,
et emendatiónem vitae, tríbuat vobis omnípotens
Pater, pius et misericors
Dóminus.-P-F : Amen.
Que le
Père tout-puissant, le Seigneur clément et miséricordieux, vous
accorde, par
votre confession, votre contrition, votre pénitence, votre réparation
et
l’amendement de votre vie, l’absolution+++
et la pleine rémission de
tous vos péchés. -P-F: Amen
-P: Sit
nomen Domini benedictum.
Que le nom du Seigneur soit
béni.
-F: Ex hoc nunc et usque in sæculum
Dès
maintenant et dans tous les siècles.
-P: Dómine, exáudi oratiónem
meam.
Seigneur,
exaucez ma prière.
-F: Et clamor
meus ad te véniat.
Que
mon appel parvienne jusqu’à vous.
-P: Dóminus vobíscum.
Le
Seigneur soit avec vous.
-F: Et cum spíritu tuo.
Et
avec votre esprit.
-Le célébrant, incliné devant l’autel, dit la
prière suivante -P:Oremus: Venez, Seigneur, purifier nos consciences pour
qu’à son entrée notre Seigneur Jésus-Christ y trouve une demeure prête
à le recevoir.Amen
-Puis le célébrant s’unit à la prière des anges
et se recommande aux martyrs dont il embrasse les reliques (la Pierre
d’Autel)
-P:Oremus:Et joignez nos voix à celles de vos anges, en
sorte que par l’intervention de ceux qui vous louent dans le bonheur du
ciel,
nous puissions, nous aussi, vous louer dans l’exil d’ici-bas. Amen.
-Introit:
(Voir fête du jour, Missel Romain)
-Aux Messes solennelles, le Prêtre bénit
l’encens en disant : Ab illo sanctificéris,
in cujus honóre cremáberis,
in nómine Patris,
et Fílii, et Spíritus Sancti. Amen - Que celui-là te sanctifie en l’honneur de qui
tu vas brûler, au nom du Père, du Fils et du Saint Esprit. Amen-
Il encense l’Autel puis l’Assemblée -P:Seigneur, que ma prière s'élève comme l’encens devant
votre face. Amen
- Kyrie :
P-F : Les
bras du prêtre s’élèvent très haut dans le ciel au Kyrie:
|
Kyrie eleison.
Kyrie eleison.
Kyrie eleison.
Christe eleison.
Christe eleison.
Christe eleison.
Kyrie eleison.
Kyrie eleison.
Kyrie eleison.
|
Seigneur, ayez
pitié de nous.
Seigneur, ayez pitié de nous.
Seigneur, ayez pitié de nous.
Christ, ayez
pitié de nous.
Christ, ayez pitié de nous.
Christ, ayez pitié de nous.
Seigneur, ayez
pitié de nous.
Seigneur, ayez pitié de nous.
Seigneur, ayez pitié de nous.
|
-Pendant
les Messes des Défunts du Carême et de l’Avent on omet le Gloria.
|
Gloria
|
|
|
P-F: Gloria in excelsis Deo, et in
terra pax hominibus bonae
voluntatis. Laudamus te, benedicimus
te, adoramus te, glorificamus
te. Gratias agimus
tibi propter
magnam gloriam tuam.
Domine Deus rex coelestis, Deus Pater omnipotens. Domine Fili
Unigenite, Jesu Christe.
Domine Deus, Agnus Dei, Filius Patris. Qui tollis
peccata mundi, miserere nobis. Qui tollis
peccata mundi, suscipe
deprecationem nostram. Qui sedes
ad dexteram patris,
miserere nobis. Quoniam tu solus sanctus,
tu solus Dominus, tu solus altissimus, Jesu Christe, (Signe de Croix)+ cum Sancto Spiritu, in
gloria Dei Patris. Amen.
P: Dominus vobiscum.
F: Et cum spiritu tuo.
|
PF: Gloire à Dieu au
plus haut des cieux, Et paix sur la terre aux hommes de bonne volonté.
Nous Vous louons,
Nous Vous bénissons, Nous Vous adorons,
Nous Vous glorifions, Nous Vous rendons grâces pour Votre immense
gloire. Seigneur Dieu, Roi du ciel, Dieu le Père tout-puissant.
Seigneur Fils Unique, Jésus Christ,
Seigneur Dieu, Agneau de Dieu, le Fils du Père.
Vous Qui enlevez les péchés du monde,ayez
pitié de nous.
Vous Qui enlevez les péchés du monde, recevez notre prière. Vous Qui
êtes assis à la droite du Père, ayez pitié de nous. Car Vous seul êtes
Saint, Vous seul êtes Seigneur, Vous seul êtes le Très-Haut, Jésus
Christ, (Signe de Croix) +Avec le Saint-Esprit, dans la
gloire de Dieu le Père. Amen.
P: Le Seigneur soit avec vous.
F: Et avec votre esprit.
|
-Oraison Ordinaire des Prophètes commémorant le
règne de Clovis : Oraison Ordinaire des Prophètes commémorant
le règne de Clovis
-P: Oremus : Vous vous êtes levé pour nous, véritable Soleil
de justice et Corne d’Huile du Salut, ô Jésus-Christ.Vous
êtes descendu du ciel en qualité de Rédempteur du genre humain. Vous
nous as
suscité un puissant sauveur Père céleste.et Vous etes
né dans la maison de David eu égard aux oracles des premiers, désirant
racheter
votre propre peuple et détruire l'acte de notre ancienne faute afin de
nous
découvrir le triomphe de la vie éternelle.C'est
pourquoi maintenant nous vous supplions, afin que, dans les entrailles
de votre
miséricorde, vous vous montrez à nos esprits, Ô salut éternel, et que
vous
fassiez de nous des serviteurs de la justice, étant délivrés de notre
inique
ennemi, et que,méprisant toute erreur
mortelle, nous
puissions, en suivant la voie droite de la paix, vous servir avec
sagesse, Ô
Sauveur du monde.Per eúndem Dóminum
nostrum Iesum Christum,
Fílium tuum,
qui tecum vivit
et regnat in unitáte
Spíritus Sancti Deus. Per omnia sǽcula sæculórum. Amen
- Par le même
Jésus-Christ, votre
Fils, notre Seigneur, qui, étant Dieu, vit et règne avec vous dans
l'unité du
Saint-Esprit. Dans tous les siècles des siècles. Amen
-Oraison - Voir propre de la fête du jour
(Missel Romain)
-P: Dominus vobiscum.
-F:Et cum spiritu tuo. Oremus
(Oraison du Jour) Conclusion de la Collecte :
Per eúndem Dóminum
nostrum Iesum Christum,
Fílium tuum,
qui tecum vivit
et regnat in unitáte
Spíritus Sancti Deus. Per omnia sǽcula sæculórum. Amen
Par le même Jésus-Christ, votre Fils, notre
Seigneur, qui, étant Dieu, vit et règne avec vous dans l'unité du
Saint-Esprit.
Dans tous les siècles des siècles. Amen
-Épître: Voir Lecture
de la fête du jour (Missel)
-P: Dominus vobiscum.
-F:Et cum spiritu tuo.
Le Seigneur soit avec vous. Et avec votre esprit. Prions
À l’'Ambon le célébrant dit fait la Lecture
de L’Épître du Bienheureux Apôtre …. Aux…:
-P: Lectio Epistolae
Beatae … Apostoli… Ad ….
(Voir
Missel, fête du jour, ou écouter le prêtre la réciter). Les
Fidèles disent avec le prêtre à la fin de la lecture:
-F:Deo Gratias
-
Nous rendons
grâces à Dieu.
-Graduel du Benedictio : Cantique des Trois Enfants la Fournaise commémorant la
conversion du
Roi Wisigoth Recarède
-P:
Béni êtes-vous, Seigneur, Dieu de nos pères,digne
de louanges, glorieux et hautement célébré
durant tous les siècles.Béni est le saint
nom de
votre gloire,digne de louanges et
hautement célébré
dans tous les siècles.Béni êtes-vous !
Bénissez le Seigneur,soleil
et lune, étoiles
du ciel, terre et eau, air et feu,hommes
religieux,
animaux et minéraux.Louez le Seigneur Dieu
des dieux,rendez-lui hommage, car sa
miséricorde s'étend à tous
les siècles.Ananias, Azarias
et Misaël, bénissez le Seigneur, louez-le
et
exaltez-le durant tous les siècles,car il
vous a
tirés de l'enfer, sauvés de la mort,délivrés
du
milieu des flammes ardentes et tirés du feu ! Benedictus
es Domine Hosanna!
Benedictus qui venit in nomine Domini+! Gloria Patri, et Filio,
et Spiritui Sancto.Sicut
erat in principio et nunc,et
semper, et in saecula saeculorum
! Amen - Bénis es-tu Seigneur, Hosanna ! Béni est celui qui vient au
nom du
Seigneur ! Gloire au Père,au
Fils et au Saint Esprit, aux siècles des siècles ! Amen
-Le prêtre revient au milieu de l’autel. Il
récite une prière à voix basse les bras en croix contre la poitrine
afin de se
préparer à annoncer et proclamer l’Évangile :
-P:
Seigneur, ouvrez mes lèvres, et ma bouche
publiera vos louanges. Amen
-Trisagion du Sanctus
Deus Archangelum, le Célébrant voile
l’Evangile avec un voile
sacré puis conduit en procession l’Evangile en
l’élevant, en récitant le Trisagion :
-P-F: +Hágios
o Theós,Sanctus Deus Archangelum,Hágios
Ischyrós.Sanctus Fortis ,Hágios Athánatos, eléison himás.Sanctus
Immortalis,
miserere nobis. Gloria Patri, et Filio,
et Spiritui Sancto.Sicut
erat in principio et nunc,et semper, et in saecula
saeculorum. Amen
+Saint Dieu des Archanges, Saint Fort, Saint
Immortel, fais-nous miséricorde. Gloire au Père, au Fils et au
Saint-Esprit.
Comme au commencement, maintenant et toujours dans les siècles des
siècles.
Ainsi soit-il.
-Psaume Lucernaire : Le célébrant allume
le Chandelier à sept branches, rappel des sept dons de l’Esprit-Saint,
qui va
illuminer l’Évangile -P:Lumière joyeuse de la sainte gloire du Père immortel,
céleste, saint et bienheureux, ô Jésus Christ.Parvenus
au coucher du soleil, voyant la lumière du soir, nous chantons Dieu :
Père+,
Fils+ et Saint-Esprit+.Il est digne, en
tout temps,
de Vous célébrer avec des voix saintes, ô Fils de Dieu qui donnez la
vie ;
aussi le monde Vous glorifie. Amen
-Evangile : Voir
Lecture de la fête du jour (Missel Romain) : À l’Ambon le célébrant
Encense
l’Évangile recouvert du voile sacré, le signe et l’embrasse et l’élève au dessus du Chandelier à 7 Branches illuminé
puis il dit :
-P:Voici les saints évangiles.J’y
crois : je le confesse!
-P: Dóminus vobíscum.(Le
Seigneur
soit avec vous)
-F: Et cum spíritu tuo.(Et
avec votre esprit)
-Le Célébrant et les fidèles se signent de la
Croix avec le Pouce le front, la bouche et le coeur
puis le célébrant encense l’évangile et commence la lecture -P : † Sequentia
Sancti Evangelii secundum N….. († Suite
du Saint Evangile selon Saint N…..)
-P-F: Gloria tibi Domine. (Gloire
à Vous Seigneur.)
A la fin de la lecture de l’Evangile on dit -P-F: Laus Tibi Christe (Louange à vous o Christ)
-P:Que Par la Lecture de ces Saints Évangiles tous
nos péchés soient effacés+++ Amen.
-Supplications
de Saint Martin
-P-F: Disons tous : Kyrie Eleison. De
tout notre cœur, et de tout notre esprit, nous vous adorons Seigneur.Pour
la paix la plus durable, et une
situation prospère pour le Royaume, nous te supplions, Kyrie
Eleison. Pour l’Eglise Catholique, qui est établie en cette
chapelle,
nous vous invoquons, Kyrie Eleison.Pour
notre Roy … et la mémoire
de notre Roy Très Chrétien Clovis, et pour toute sa chevalerie Roy des Roys; Kyrie
Eleison.Pour la salubrité de
l’air et des
fruits et pour la fécondité de la terre, bon dispensateur des biens,Kyrie Eleison.Pour
cette Patrie et sa préservation, nous te prions,Kyrie Eleison. Pour ceux qui sont infirmes et ceux qui sont
atteints de diverses maladies, guérissez-les,Kyrie
Eleison. Pour la rémission des péchés, et leur correction, nous
vous invoquons,Kyrie Eleison. Exaudi
nos, Deus, in omni oratione nostra,
quia potens est.Amen
- Exaucez-nous, Dieu, en toutes
nos prières, car vous êtes puissant.Amen
|
Credo
|
-Le Crédo peut être omis aux Messes Votives et aux Messes
des Défunts.
|
|
P-F: Credo in unum Deum, Patrem omnipotentem,
factorem coeli et terrae, visibilium omnium et invisibilium. Et in unum Dominum Jesum Christum, Filium
Dei unigenitum. Et ex Patre
natum ante omnia saecula. Deum
de Deo, lumen de lumine, Deum verum de Deo
vero. Genitum, non factum, consubstantialem Patri : per quem omnia facta sunt. Qui propter
nos homines, et propter
nostram salutem descendit de coelis.
(On se met à genoux)
ET INCARNATUS EST DE SPIRITU SANCTO EX MARIA VIRGINE ET HOMO FACTUS EST.
Crucifixus etiam pro nobis: sub Pontio Pilato passus, et sepultus est. Et resurrexit
tertia die, secundum Scripturas. Et ascendit
in coelum : sedet
ad dexteram Patris.
Et iterum venturus
est cum gloria, judicare vivos et mortuos: cujus regni non erit
finis. Et in Spiritum Sanctum,
Dominum et vivificantem: qui ex Patre procedit. Qui cum Patre
et Filio simul
adoratur et conglorificatur: qui locutus est
per prophetas. Et unam,
sanctam, Catholicam et Apostolicam
Ecclesiam. Confiteor unum
baptisma in remissionem peccatorum.
Et exspecto resurrectionem
mortuorum. +
(Signe de Croix) Et vitam venturi saeculi. Amen.
|
P-F: Je crois en un
seul Dieu, Le Père tout-puissant, Créateur du ciel et de la terre, de
l'univers visible et invisible. Et en un seul Seigneur Jésus Christ, le
Fils Unique de Dieu, Né du Père avant tous les siècles. Il est Dieu né
de Dieu, Lumière née de la Lumière, vrai Dieu né du vrai Dieu,Engendré, non
pas créé, consubstantiel au Père, par Qui tout a été créé. Pour nous
les hommes et pour notre salut, Il descendit des cieux. (On
se met à genoux)
IL A PRIS CHAIR DE LA VIERGE MARIE PAR ACTION DU SAINT-ESPRIT, ET IL
S'EST FAIT HOMME.
Crucifié pour nous sous Ponce Pilate, Il souffrit Sa Passion et fut mis
au tombeau. Il ressucita le troisième
jour, conformément aux Ecritures, Et Il monta au ciel, où Il siège à la
droite du Père . Il reviendra dans la
gloire pour juger les vivants et les morts ; Et Son règne n'aura pas de
fin. Je crois en l'Esprit Saint, Qui est Seigneur et Qui donne la vie :
Il procède du Père. Avec le Père et le Fils, Il reçoit même adoration
et même gloire : Il a parlé par les prophètes. Je crois à l'Eglise une,
sainte, catholique et apostolique. Je reconnais un seul baptême pour la
rémission des péchés. Et j'attends la résurrection des morts.
+ (Signe de Croix) Et la vie du monde à venir. Amen.
|
-Liturgie Eucharistique: A
l’Offertoire le prêtre reçoit les offrandes des fidèles et bénit le
pain, les
galettes (jour des Rois, Epiphanie), les œufs (Pâques), les roses
(Pentecôte),
les croix d’herbes (Saint Jean d’été).
-P: Dominus vobiscum. Le Seigneur soit
avec vous.
-F: Et cum spiritu
tuo. Et
avec
votre esprit.
-P: Oremus
-Offertoire
: (Propre du Jour, voir Missel
Romain)
-En
découvrant le voile du calice, le célébrant dit
-P:Que rendrai-je au
Seigneur pour tant de grâces qu’il
m’a faites ? Je prendrai le calice du salut, et j’invoquerai le nom du
Seigneur. Amen
-Puis
Il dépose la patène sur le corporal ; puis, étendant les mains sur
l’hostie, il
dit
-P: Jésus
dit à ses disciples : «Je suis le pain vivant
descendu du
ciel; si quelqu’un mange de ce pain, il vivra éternellement.Et
le soldat Lui perça le côté.Amen
-Le
Célébrant bénit les Burettes d’Eau et de Vin et à droite de
l’autel, en mettant du vin et de l’eau dans le calice, le prêtre dit :
-P:Benédicite In Nomine Patris + et Filii + et Spiritui
Sancti+Amen.De látere Dómini
nostri Jesu
Christi exívit sanguis+
et aqua+ pro redemptióne mundi témpore passiónis, id est, mystérium
sanctae Trinitátis:
Joánnes Evangelísta
vidit et testimónium
perhíbuit, et scimus quia verum est testimónium
ejus.
- Bénissez Au Nom du Père+ du Fils
et du Saint Esprit+ Amen. Du côté de notre Seigneur Jésus-Christ
jaillirent
du sang et de l’eau pour la rédemption du monde, lors de la passion :
Mystère
la Sainte Trinité; l’évangéliste Jean l’a
vu et en
témoigne, et nous savons que son témoignage est vrai.
-Puis
le Célébrant bénit le Calice en l’élevant vers l’Autel et en disant: +++Par ses plaies nous avons été guéris. Venez et je vous
montrerai l’Épouse
qui a l’Agneau pour époux. Amen
-Procession
de l’Oblation de Saint Jean Cassien : le Célébrant saisit le Ciboire
Voilé et
le mène en procession vers l’Autel en bénissant avec le St Vase
l'Assemblée
puis en bénissant toujours avec le St Vase l’Autel en signe de
préparation
l’Offrande des Saints Dons en disant le Sonus Gallican
-P: ++Nous qui représentons mystiquement les Chérubins,et
qui chantons à la Trinité vivifiante l'hymne
trois fois saint,mettons maintenant de
côté toutes
les préoccupations terrestres,afin de
recevoir le Roi
de tous,escorté invisiblement par les
armées angéliques.La Vierge aujourd’hui
met au monde l’Éternel, et
la terre offre une grotte à l’Inaccessible. Les anges et les pasteurs
Le
louent, et les mages avec l’étoile s’avancent, car Tu es né pour nous,
Enfant nouvelet, Dieu prééternel. Alléluia,
alléluia, alléluia. Amen
-Le
célébrant dépose le Ciboire sur l’Autel devant le Tabernacle et le
dévoile puis
revient au milieu de l’autel et offre ensemble l’hostie et le calice en les élevant et en disant
-P: l’offrande
que nous vous présentons : acceptez-la, Dieu tout-puissant, avec
bienveillance,
et pardonnez les péchés de tous ceux qui vous l’offrent et de ceux pour
qui
elle vous est offerte.Voyez l’humilité de
nos âmes et
la contrition de nos cœurs : accueillez-nous, Seigneur, et que notre
sacrifice
s’accomplisse aujourd’hui devant vous de telle manière qu’il vous soit
agréable, Seigneur Dieu.Amen
-En retournant au milieu de l’autel, il dit la
prière du Voile trois fois en agitant le voile au
dessus
du Calice signifiant la descente du Saint Esprit parachevant la
préparation des
Saintes Oblations :
-P:
Venez, Esprit-Saint:Veni, Sancte Spíritus x3: remplissez
les cœurs de
vos fidèles, et allumez en eux le feu de votre amour.Alléluia.alléluia,
alléluia.Amen
-le prêtre bénit l’encens
-P: Par l'intercession du Bienheureux Michel Archange, debout
à droite de l'autel des parfums, et de tous Ses élus,que
le Seigneur daigne bénir cet encens et
le recevoir en odeur de suavité : Ab
illo sanctificeris
in cujus
honore cremaberis, in nomine †Patris et Filii et Spiritus
Sancti. Amen - Sois béni par Celui en l’honneur de qui tu vas
être
brûlé, au nom du† Père et du Fils et
du Saint-Esprit. Ainsi soit-il.
-puis encense les offrandes et l’autel;
puis il encense le peuple:Dans la grotte, dans le tombeau, dans le sein virginal,Vous vous êtes reposez, ô Créateur du
Ciel et de
la Terre. Condescendez à Vous reposez en
nous, ô
Sauveur de l’homme. Le noble Joseph descendit du bois votre corps très
pur,
l’enveloppa d’un linceul immaculé, le déposa couvert d’aromates dans un
sépulcre neuf. Votre sépulcre, ô Christ, est plus resplendissant que
les
demeures royales, chambre nuptiale et source de la résurrection. Que
cet encens béni par Vous,
Seigneur s'élève en Votre présence et que descende sur nous Votre
miséricorde. Amen
-Le Prêtre se rend à droite de l’autel, où il
se lave les doigts en signe de pénitence
-P:
Lavabo inter innocéntes manus meas:
et circúmdabo altáre
tuum, Dómine.
Ut áudiam vocem laudis,
et enarrem univérsa
mirabília tua. Amen
Je
lave mes mains dans l’innocence et fais le tour de votre autel,
Seigneur, en
faisant retentir des chants de louange, en proclamant chacun de vos prodiges.Amen
-Le Prêtre se tourne vers les fidèles et les
invite à prier pour lui et avec lui
-P : Orate
pro me, fratres, ut meum
Sacrificium et vestrum fiat acceptabile
ante conspectum Dei.
Priez pour moi, mes frères, afin que mon sacrifice,
qui est aussi le vôtre, soit favorablement reçu de Dieu.
-F:Dóminus Deus omnípotens suscípiat sacrifícium
de
ore tuo et de mánibus
tuis, ad utilitátem
sanctae suae
Ecclésiae,
et ad salútem omnis
pópuli christiáni,
et ad remédium ómnium
fidélium defunctórum.
Le Célébrant répond -P: Amen -
Que le
Seigneur Dieu tout puissant reçoive ce sacrifice, de votre bouche et de
vos
mains, pour le bien de sa sainte Église, le salut de tout le peuple
chrétien et
le soulagement de tous les fidèles défunts.-P:
Amen
-le célébrant dit la secrète. (Secrète au
Propre du Jour, voir Missel)
-Bénédiction du Peuple du Missale
Francorum
-P :Bénissez, ô Seigneur, votre famille qu'il vous a
plu de façonner dans la boue et de vivifier
ensuite par le bain sacré du baptême. Accordez que ceux à qui la vie
éternelle
a été arrachée par la gourmandise d'Eve et auxquels la mort sur la
croix
apporta la rédemption puissent glorifier les mérites de votre avénement.
Faites en sorte que le perfide adversaire ne trouve en eux rien à
emporter, que
la Divine pitié ne trouve en eux rien à repousser. Mais
en
revanche, lorsque sera arrivé le jour du jugement, faites qu'ils
soient
convoqués au Ciel par la trompette des Anges, qu'ils soient admis pour
leurs
mérites à la récompense éternelle et qu'ils reçoivent enfin la palme du
triomphe.
Per Christum Dominum
Nostrum. Amen - Par Christ Notre Seigneur.
Amen
-Lecture des
Diptyques : -Memento des Vivants :-C: Le célébrant pose ses mains jointes sur
l’Autel
-P:Souvenez - vous, Ô Seigneur, de vos serviteurs, et
servantes….. et …… de tous ceux ici
présents, la foi
desquels vous est connue et la dévotion notoire, qui vous offrent ce
sacrifice
de louange pour eux et pour tous les leurs, pour l’espérance de leur
salut,
pour la rédemption de leurs âmes, et de leur prospérité, vous rendent
leurs
vœux, Ô Dieu Éternel
Vivant et
Vrai.
-Memento des Défunts:
Le célébrant joint les mains sur l’Autel:
-P: Souvenez-vous
aussi, Ô Seigneur de vos serviteurs et servantes ……. qui
nous ont précédés avec le signe de la foi, et dorment du sommeil de la
paix. À
eux, Seigneur et à tous ceux qui reposent en Christ, nous vous prions
que vous
octroyez le lieu de rafraîchissement, de lumière et de paix.
-P:Per Christum Dominum Nostrum.Amen
-Par
Christ Notre Seigneur. Amen
-Collectio Post-Nomini Wisigothique
-P : Par votre ordre, Seigneur et notre Dieu, nous
vous présentons ces mystères glorieux sur l’autel du pardon;
pour ceux dont les noms sont inscrits sur les diptyques, les vivants et
les
morts, pour notre salut et celui du monde entier lors de la seconde
venue du
ciel de notre Seigneur Jésus Christ, lui seul sauveur du monde,
coéternel à
vous Père et au Paraclet. A vous
louange, bénédiction, sagesse, honneur, puissance, force et action de
grâce.
-P:Per Christum Dominum
Nostrum. Amen
- Par Jésus Christ Notre Seigneur. Amen
-Baiser
de Paix
-P:Oremus: Seigneur
Jésus-Christ, qui avez dit à vos Apôtres : je vous laisse ma paix, je
vous
donne ma paix, ne regarde pas mes péchés, mais la Foi de votre Église.
Donnez-nous la paix et l’union selon votre volonté.
Puis
Le Prêtre embrasse la Patène contenant
l’Hostie et le Baiser de Paix et donne la Paix au Fidèles -
P: Pax, fides et charitas
et communicatio corporis et sanguis Domini sit semper vobiscum.
Que la
paix, la foi, la charité et la communion du corps et du sang du
Seigneur soient
toujours avec vous.
Les fidèles -F:
Et Cum Spirituo Tuo -
Et Avec
Votre Esprit.
le
célébrant dit ensuite à haute voix :
-P:Per Dominum nostrum Iesum Christum Filium tuum, qui tecum vivit et regnat,
in unitate Spiritus
Sancti, Deus,
per omnia saecula
saeculorum. Amen
-Par
Notre Seigneur Jésus-Christ, votre Fils, qui, étant Dieu, vit et règne
avec
Vous, en l'unité du Saint-Esprit, dans tous les siècles des siècles.
Ainsi
soit-il.
-Préface
: -Coutume Gallicane:
Au Sursum Corda et au Gratias Agamus le célébrant élève la Patène avec la
main droite, et
laisse la Patène
Voilée jusqu'à la Doxologie, sauf à la Consécration.
-P: Dominus vobiscum. -F: cum spiritu
tuo.
Le Seigneur soit avec vous. Et avec votre
esprit.
-P:
Sursum corda.-F: Habemus ad Dominum.
Les
cœurs en haut. Nous les avons vers
le Seigneur.
-P:Gratias agamus
Domino Deo nostro. -F: Dignum est justum
est.
Rendons
grâce au Seigneur notre Dieu.
C’est chose digne et juste
-P:Vere dignum
et iustum est,æquum
et salutáre,nos tibi
semper et ubíque grátias
ágere :Dómine,
sancte Pater, omnípotens ætérne
Deus :per Christum Dóminum nostrum.Per
quem maiestátem tuam
laudant Angeli,adórant
Dominatiónes,tremunt Potestátes.Cæli cælorúmque
Virtútes ac
beáta Séraphim
sócia exsultatióne
concélebrant.Cum quibus et nostras voces
ut admítti iúbeas,
deprecámur,súpplici confessióne dicentes
: (On Sonne Trois fois
les cloches au
Sanctus)
-P-F: Sanctus,
Sanctus, Sanctus
Dominus Deus Sabaoth. Pleni sunt coeli et terra
gloria tua.
Hosanna in excelsis.(Signe de Croix)+Benedictus
qui venit in
nomine Domini. Hosanna in excelsis.
Il est
vraiment digne, juste, équitable et salutaire, que nous vous
rendions-grâces,
Seigneur, Saint, Père Tout-Puissant, Dieu Éternel. Toujours et en tous
lieux.
Par le Christ notre Seigneur. Par lequel les Anges louent votre
Majesté, les
Dominations l’adorent, les puissances tremblent, les Cieux et les
Vertus des
Cieux, et les Bienheureux Séraphins célèbrent ensemble avec joie ; Avec
lesquels aussi nous vous prions d’ordonner que nos voix soient admises
disant
par une humble confession :
(On Sonne Trois fois les cloches au Sanctus)
-P-F: Saint,
Saint, Saint le Seigneur, Dieu de l'univers. Le ciel et la terre sont
remplis
de Votre Gloire. (Signe de Croix)+
Béni soit celui Qui vient au Nom du Seigneur .
Hosanna au plus haut des cieux.
–Prière pour
l'Église: Le célébrant élève les mains au Ciel puis s’incline embrasse
l’Autel
et impose les mains au Calice puis aux indications des petites croix le
Célébrant Signe de la Croix le Calice et la Patène:
-P: Nous vous supplions donc humblement, Ô Père
très clément, par Jésus-Christ votre Fils, et demandons, que vous
receviez pour
agréables, et bénissez ces dons+, ces présents+, ces sacrifices, sans
taches+
que nous vous offrons en premier lieu pour votre Sainte Église
Catholique,
laquelle il vous plaise, pacifier, garder, unir, et régir par tout
l’univers.
Ensemble avec votre serviteur notre Pape… (notre Patriarche… notre
Évêque… ) notre Roy… et en mémoire de notre
Roy Très Chrétien
Clovis et tous les Orthodoxes qui professent la Foi Catholique et
Apostolique.
-Communicantes :
-P: Communicant
et vénérant la mémoire, en premier lieu de la Glorieuse toujours Vierge
Marie,
Mère de Dieu et de Notre Seigneur Jésus-Christ,puis
celle de son Bienheureux Époux Joseph, mais aussi de vos Bienheureux
Apôtres et
Martyrs, Marie-Madeleine,des Maries de la
Mer, Pierre,Paul, André, Jacques, Jean,
Thomas, Jacques,
Philippe, Barthélémy, Matthieu, Simon, et Thadée,Lin,
Clet, Clément, Sixte,Corneille, Cyprien,Laurent
et Chrysogone, Jean et Paul, Côme et Damien et Irénée de Lyon,Hippolyte
de Rome, et de tous vos Saints, par les mérites et les prières desquels
octroyez-nous d'être munis de l’aide de votre protection en toutes
choses.
-P:Per Christum Dominum
Nostrum.Amen - Par Christ Notre Seigneur. Amen
-Prière pour toute la Famille de Dieu, le
célébrant impose les mains au Calice et à la Patène:
Nous vous supplions donc, Seigneur, que vous
receviez, apaisé cette oblation de notre servitude, mais aussi de toute
votre
famille, et que vous disposiez toujours en votre paix et ordonniez
toujours que
nous soyons délivrés de la damnation éternelle, et unis au nombre de
vos élus.
-P:Per Christum Dominum Nostrum.Amen
- Par
Christ Notre Seigneur. Amen
-Prière Avant la Consécration : Le Célébrant
signe le Calice et la Patène :
-P:La quelle oblation nous vous prions, Ô Dieu de daigner rendre en
toutes
choses, bénite+ , souscrite+, ratifiée+, raisonnable+, acceptable+, à
ce qu’il
vous soit fait le Corps+ et le Sang+ de votre très aimé, Fils,
Jésus-Christ
Notre Seigneur Dieu.
-+ le Célébrant
Récite les Prières d’Action de
Grâce et de
l’Institution de Saint Hippolyte Ier de Rome Pape et Martyr+ (IIIeme Action
de Grâce:- Siècle) :
P:Nous vous rendons
grâces, ô Dieu,par
votre Enfant bien-aimé, Jésus Christ,que
vous nous
avez envoyé aux derniers temps comme Sauveur, Rédempteur et Messager de
votre volonté.Il est votre Verbe
inséparable par qui vous avez
tout créé et en vous avez as mis vos complaisances.Vous
l'avez envoyé du Ciel dans le sein d'une
Vierge. Il a été conçu et s'est incarné, il s'est manifesté comme votre
Fils,
né de l'Esprit et de la Vierge.Il a
accompli votre
volonté et, pour vous acquérir un peuple saint, il a étendu ses mains
tandis
qu'il souffrait pour délivrer de la souffrance ceux qui croient en
vous. Amen
-Récit de l’Institution:
-P:-Tandis qu'il se
livrait à la souffrance volontaire pour détruire la mort, briser les
chaînes du
diable, fouler l'enfer à ses pieds, répandre sa lumière sur les justes,
établir
et manifester sa Résurrection. Amen
- Consécration de l’Hostie et du Précieux Sang
- On sonne les cloches avant la Consécration une fois. Pendant
l'Élévation de
l’Hostie et du Calice on
dit selon la coutume de l’usage Gallican
-P-F :O salutáris hóstia, Quae caeli pandis óstium,
Bella premunt hostília;
Da robur, fer auxilium.
Amen
O
victime qui nous sauvez, Nous ouvrant la porte du ciel, Contre l’ennemi
qui
nous presse, Accordez-nous force et secours.Amen
Vienne
la grâce et que passe ce monde, Amen
!
Hosanna au Dieu de David. Celui qui est saint, qu’il vienne ! Celui qui
ne
l’est pas, qu’il change son cœur ! Maranatha,
Amen!
-On se met à genoux jusqu’à la fin de
l’Élévation. On peut faire un Encensement à l'Élévation de l’Hostie et
du
Calice. -P:Qui prídie quam
paterétur, accépit
panem
in sanctas ac
venerábiles manus suas, et elevátis
óculis in cælum
ad te Deum Patrem suum omnipoténtem, tibi grátias agens, bene+díxit, fregit,
dedítque discípulis
suis, dicens
: Accípite, et manducáte
ex hoc omnes : Le prêtre impose les mains sur l’Hostie et consacre le Pain
-P :
‘’HOC EST ENIM CORPUS MEUM’’.
Le Prêtre Elève l’Hostie
On sonne les cloches trois fois
Lequel
devant le jour qu’il endurat,il
prit le pain en ses Saintes et Vénérables Mains, les yeux levés au
Ciel, vers
vous Dieu son Père Tout-Puissant, vous rendant grâces, bénit+, rompit,
donna à
ses disciples, disant : Prenez et Mangez tous de Ceci :
‘’CAR CECI
EST MON CORPS.’’
-P: Simili modo póstquam cenátum est, accípiens
et hunc præclárum
cálicem
in sanctas ac
venerábiles manus suas : tibi grátias agens, bene+díxit, dedítque
discípulis suis, dicens : Accípite,
et bíbite ex eo
omnes. Le prêtre impose les mains sur le Calice et consacre le vin
-P :
‘’HIC EST ENIM CALIX SANGUINIS MEI,NOVI
ET ÆTÉRNI TESTAMÉNTI : MYSTÉRIUM FIDEI : QUI PRO
VOBIS ET PRO MULTIS EFFUNDÉTUR IN REMISSIÓNEM PECCATÓRUM.’’HAEC
QUOTIESCUMQUE
FECERITIS IN MEI MEMORIAM FACIETIS.’’
Le
Prêtre Élève le Calice.
On
sonne les cloches trois fois
Puis On sonne
les cloches une dernière fois.
Semblablement,
après qu’on eut soupé, prenant aussi cet excellent Calice en en ses
Saintes et
Vénérables Mains, vous rendant grâces, Bénit + donna à ses disciples
disant :
Prenez, et buvez tous de ceci:
‘’CAR CECI EST LE CALICE DE MON SANG. DU TESTAMENT NOUVEAU ET ETERNEL,
MYSTÈRE DE LA FOI, QUI SERA ÉPANDU POUR VOUS, ET POUR PLUSIEURS EN
REMISSION
DES PECHES. TOUTES QUANTES FOIS QUE VOUS FEREZ CES CHOSES,VOUS
LES FEREZ EN MÉMOIRE DE MOI.’’
-Anamnèse : Le prêtre saisit la patène et le
Calice et les élèves au dessus de l’Autel
-P: Nous souvenant donc de votre Mort et de votre
Résurrection nous vous offrons le Pain et le Vin, nous vous rendons
grâces de
nous avoir jugés dignes de nous tenir devant vous et de vous servir et
d'accomplir notre Ministère Sacerdotal. Amen
-Le Célébrant impose
les mains au
dessus de la la Patène et le Calice
et fait
battre ses mains comme les ailes du Saint Esprit en disant l’ÉPICLÈSE
SUR LES
DONS (Hostie et Calice) en disant 3 fois ‘’Veni
Sancte Spiritus’’
-Epiclèse -P:Et nous vous demandons d'envoyer votre Esprit
Saint: ‘’Veni Sancte Spiritus
x3’’ sur l'
offrande de votre
Eglise sainte, de rassembler dans l' unité tous ceux qui la reçoivent.
Qu'ils
soient remplis de l' Esprit Saint qui
affermit leur
foi dans la vérité. Que nous puissions vous louer et vous glorifier par
votre Enfant, Jésus
Christ. Amen, Amen, Amen.
-Unde et Memores:Le Célébrant met les bras
en croix et dit
-P:
Dont aussi, nous, vos serviteurs, Ô
Seigneur, mais aussi votre Saint peuple, mémoratifs de la Passion si
heureuse
de Christ votre Fils notre Dieu, comme aussi de la Résurrection des
Enfers,
mais aussi de la Glorieuse Ascension aux Cieux. Nous offrons à votre
excellente
majesté, de vos dons et présents :
Une
Hostie Pure+, une Hostie Sainte+, une Hostie Immaculée+, un Pain Saint
de Vie
Éternelle+, et un Calice de Salut perpétuel+.
-Mémoire des Anciens Sacrifices : Le célébrant
impose les mains au Calice et à la Patène :
-P:
Sur lesquelles choses daignez regarder d’un
aspect propice et serein, et les avoir agréables, comme vous avez
daigné
d’avoir agréables, les dons de votre enfant le Juste Abel, les
sacrifices de
Noé, et le sacrifice de notre Patriarche Abraham père de notre race, et
celui
que vous offrit Grand Prêtre Melchisédech, Sacrifice Saint, Hostie
Immaculée.
-Le Célébrant s’incline profondément les bras
croisés sur la poitrine :
-P: Nous vous prions humblement, Ô Dieu Tout-Puissant, commandez
que ces
choses soient portées par les mains de votre Saint Ange devant votre
Sublime
Autel à la venue de votre Divine Majesté, à ce qu’autant de nous qui
aurons
reçu, par la participation de cet Autel, le Corps Sacro-Saint+ et le
Sang+ de
votre Fils, soyons remplis de toute bénédictions Célestes+
(le Prêtre se signe) et grâces.Per Christum Dominum Nostrum. Amen - Par
Christ
Notre Seigneur. Amen
-Nobis quoque
peccatóribus: Le célébrant se frappe trois fois la poitrine -P:Et à nous pareillement qui sommes pécheurs, vos
serviteurs, espérant de la multitude de vos miséricordes, daignez de
donner
quelque part et société, avec vos Saints Apôtres et Martyrs.
Avec :
Jean, Etienne,Mathias,
Barnabé, Ignace,Alexandre, Marcellin,Pierre,Félicité,Perpétue, Agathe,Lucie,Agnès,Cécile,Anastasie,Et
et avec tous
vos Saints, en la compagnie desquels nous vous prions que vous
admettiez, non
estimateur du mérite, mais donateur de pardon. Per Christum
Dominum Nostrum -
Par Christ notre Seigneur. Amen
-Conclusion du Canon:Le
Célébrant signe les Saints Dons:
-P: Par lequel O Seigneur, créez ces choses
toujours, bonnes, les sanctifiez+, vivifiez+, bénissez+, et nous donnez.
-Epiclèse sur les Communiants de Saint
Hippolyte - le Célébrant une Main tendu vers les Saints Dons et l’autre
vers
les fidèles dit : Humblement,
nous vous demandons qu’en ayant part au corps et au sang du Christ,
nous soyons
rassemblés par l’Esprit Saint en
un seul
corps. Amen
-Le Célébrant se tourne vers les Fidèles ou
l’Autel et brandissant vers eux la Patène et le Calice et ils les bénit
avec et
dit face à l’Autel en élevant les Saints Dons:
Le
lion de la tribu de Juda, le rejeton de David, est vainqueur, alléluia. Celui qui est assis
sur les chérubins,
est vainqueur, alléluia,alléluia
! Amen.
-Puis Le Prêtre élève le Calice et l’Hostie qui
surmonte le Calice pour
l’adoration des fidèles. Le servant
sonne une fois (bref
roulement).en disant la Doxologie :
-Doxologie -P:Per ipsum, glória tibi, et honor
Patri + et Fílio, + cum Sancto Spíritu + in
Ecclésia Sancta tua, nunc et in saecula sæculórum. Amen. - Par lui, gloire à vous, et honneur au Père+ et
au Fils+, avec l' Esprit Saint+, dans votre
Eglise
Sainte, maintenant et dans les siècles des siècles ! Amen.
-Le Célébrant pose l’Hostie sur la Patène
devant le Calice, et Voile le Calice avec le Purificatoire selon
l’usage
Gallican.
-Pater Noster
-P-F : -Récité avant la Fraction
du Pain coutume grecque : Le Célébrant et les fidèles en contemplant
les Saints
Dons (Calice voilé par le Purificatoire et Hostie posée sur la Patène)
élèvent
les bras en Croix au Ciel et disent ensemble le Notre Père :
Oremus. Praeceptis salutaribus moniti,
et divina institutione
formati, audemus
dicere : Pater noster,
qui es in coelis ; sanctificetur
nomen tuum ; adveniat
regnum tuum: fiat voluntas tua Sicut
in coelo et in terra. Panem
nostrum quotidianum da nobis hodie ; et dimitte nobis debita nostra, sicut
et nos dimittimus debitoribus
nostris. Et ne nos inducas in tentationem.Sed libera nos a malo.Amen.
Étant
admonestés par préceptes salutaires, et informés par insitution
Divine, nous osons dire : Notre Père qui est aux Cieux, votre nom soit
sanctifié. Votre royaume advienne. Votre volonté soit faite au Ciel et
en la
terre. Donnez-nous aujourd’hui notre pain quotidien. Et quittez-nous
nos
dettes, comme nous aussi nous les quittons à nos débiteurs et ne nous
induisez
point en tentation mais délivrez nous du
mal. Amen
-Doxologie
-PF : Car c’est à Vous qu’appartiennent le Règne,
la Puissance et la Gloire,
Per Omnia saecula
sæculórum. Amen
Pour
les siècles des siècles. Amen
- Le Célébrant
se signe avec la Patène puis l’embrasse :
-P: +Délivrez-nous,
Seigneur, nous en vous en
prions, de tous les maux, passé, présent et futur et intercédant la
Bienheureuse et Glorieuse toujours Vierge Mère de Dieu, Marie, et vos
Bienheureux Apôtres Pierre et Paul, et André, et tous les Saints.
Donnez propice
la paix à nos jours, à ce que aidés par le secours de votre
miséricorde, et
nous soyons toujours libre du péché et en assurance contre tout trouble.Per eúndem Dóminum
nostrum Iesum Christum,
Fílium tuum,
qui tecum vivit
et regnat in unitáte
Spíritus Sancti Deus. Per omnia sǽcula sæculórum. Amen - Par le même Jésus-Christ, votre Fils, notre
Seigneur, qui, étant Dieu, vit et règne avec vous dans l'unité du Saint-Esprit.Dans tous les siècles des siècles.Amen
-Fraction du Pain : l’’Ancienne "Commixilo"
gallicane, le prêtre brise l'hostie en 9
morceaux en Mémoire des 9 Mystères du Christ de l’Année Liturgique
qu'il
dispose en forme de Croix sur la patène en disant les 9 Mystères
-P :La table est dressée, l’Agneau de Dieu est
immolé, partagé mais non divisé, mangé mais jamais consommé. Le vin est
mêlé,
le sang est répandu. Buvons à la coupe inépuisable, quittons
l’ignorance et
proclamons un seul, unique et redoutable mystère :
1. Corporatio,
2. Nativitas,
3. Circumcisio,
4. Apparitio,
5. Passio,
6. Mors,
7. Ressurectio,
8. Gloria,
9. Regnum
1.L’Incarnation,
2. La
Nativité,
3. La
Circoncision,
4.
L’Apparition,
5. La
Passion,
6. La
Mort,
7. La
Résurrection,
8. La
Gloire,
9. Le
Règne
-Puis le célébrant dévoile le Calice et prélève
la parcelle centrale de l’Hostie qu'il fera tomber dans le Calice avec la quelle il bénit le Vin Consacré dans le
Calice, en
disant
-P: Pax + Dómini sit + semper vobíscum
+ (Que la Paix+ du Seigneur+ soit toujours avec
vous+)
-F: Et cum spíritu
tuo. (Et
avec votre Esprit)
-Puis le célébrant laisse tomber la parcelle
d’hostie dans le Calice en disant :
-P: Que ce mélange sacré du Corps et du Sang de
notre Seigneur Jésus-Christ me procure, et à tous ceux qui vont le
recevoir, la
santé de l’âme et du corps, et nous prépare d’une manière salutaire à
mériter
la vie éternelle. Per eumdem Christum Dominum nostrum.Amen Par le même Christ Notre Seigneur.Amen
-AGNUS DEI: le
célébrant et les fidèles chantent ou disent ensembles à voix haute, au Miserère Nobis le
prêtre et les
fidèles se tapent trois fois la poitrine
-P-F:
Agnus Dei, qui tollis peccáta mundi : miserére nobis
(Agneau
de Dieu qui
enlevez les péchés du monde, ayez pitié de nous).
Agnus Dei, qui tollis peccáta mundi : miserére nobis
(Agneau de
Dieu qui enlevez les péchés du monde, ayez pitié de nous).
Agnus Dei, qui tollis peccáta mundi : dona nobis pacem.
Amen
(Agneau de Dieu qui enlevez les péchés du
monde, donnez-nous la paix).
-Note : Aux Messes pour les Défunts le Misérere Nobis est
remplacé par
: Dona Eis
Requiem
et le Dona nobis pacem
par
: Dona eis
requiem sempiternam.Amen
- Préparation à la Sainte Communion de Saint
Hippolyte
-P: Nous vous supplions encore Dieu Tout-Puissant,
Père de Notre Seigneur Jésus-Christ, de nous accorder que nous
recevions avec
bénédiction ce Saint Mystère : Qu’il ne puisse condamner personne
d’entre nous
mais qu’il rende dignes tous ceux qui reçoivent le Saint Mystère, le
Corps et
le Sang du Christ, Seigneur Tout Puissant Notre Dieu. Amen
-Tourné vers les fidèles, le Prêtre élève
l’Hostie Consacrée au-dessus du Calice
-P: ECCE AGNUS DEI,
ECCE QUI TOLLIS PECCATA MUNDI.
Voici
l’Agneau de Dieu, voici Celui qui enlève les péchés du monde.
-Le Prêtre et les Fidèles se tapent trois fois
la poitrine en récitant la prière du Centurion en préparation à
recevoir la
Sainte Communion :
-F: DOMINE NON SUM
DIGNUS ut intres sub
tectum meum, sed
tantum dic
verbo, et sanabitur anima mea - Seigneur,
je ne suis pas digne que vous entriez sous mon toit, mais vous n’avez
qu’un mot
à dire et mon âme sera guérie.
-Prières
de Préparation à la Sainte Communion -P: Pour la Communion au Saint Corps :Je recevrai le pain du ciel et j’invoquerai le
Nom du Seigneur. Salut, ô très Sainte chair du Christ. Amen
Pour la Communion au Saint Sang : Je
prendrai le Calice du salut ce Graal et j'invoquerai le Nom du Seigneur. Salut,
breuvage Céleste qui m’est doux avant tout et par-dessus tout. Amen
-Ensuite le Prêtre communie au Corps et au Sang
du Seigneur en disant et en traçant un signe de Croix avec l’Hostie et
avec le
Calice :
-P:Corpus et Sanguis Domini Nostri Iesu Christi sint
in remissionem peccatorum
Meorum
et custodiat animam
Meam in vitam aeternam.
Amen.
Que le
Corps et le Sang de Notre Seigneur Jésus-Christ soient pour la
rémission de mes
péchés et gardent mon âme pour la vie éternelle. Amen.
-Le Célébrant donne la Sainte Communion aux
fidèles en trempant l’Hostie dans le Calice dans le Vin Consacré pour
donner
aux fidèles la Communion sous les Deux Espèces Consacrées, les fidèles
communient à genoux et reçoivent la Communion sur la langue :
-P:Corpus et Sanguis Domini Nostri Iesu Christi sint
in remissionem peccatorum
tuorum
et custodiat animam
Tuam in vitam aeternam.
Amen
Que le
Corps et le Sang de Notre Seigneur Jésus-Christ soient pour la
rémission de tes
péchés et gardent ton âme pour la vie éternelle. Amen.
-Prière de Saint Césaire d’Arles
pour
l’Offrande la Sainte Communion en mémoire du Miracle de Saint Martin de
Tours : Venite Populi
-P-F: Venez,
peuples, approchez-vous du mystère sacré et immortel, et de ces
prémices
offerts : avec crainte et foi, avançons, avec des mains pures,
communions au
don de la pénitence ; car l’Agneau de Dieu pour nous au Père s’est
offert en
sacrifice ; c’est lui seul que nous adorons, c’est lui seul que nous
glorifions, avec les Anges en clamant : Alleluia,Alleluia,Alleluia,
Amen.
-Prière du Tricanon Wisigoth
pour la l’Offrande
de la Sainte Communion : Gustate et Videte:
-P-F: Goûtez et voyez combien doux est le
Seigneur. Alleluia, alleluia, alleluia. Je bénirai le Seigneur en
tout temps,
toujours sa louange sera dans ma bouche. Le Seigneur rachètera les âmes
de ses
serviteurs, et tous ceux qui espèrent en lui ne seront point abandonnés.Glória
et honor Patri, et Fílio,
et Spirítui Sancto,
in sæcula sæculórum.
Amen-Gloire et honneur au Père, et au Fils, et au
Saint-Esprit, dans les siècles des siècles. Amen.
-Prière Après la Communion de Saint Hippolyte :
le célébrant purifie la Patène et le Calice et les Révoiles
-P: O Dieu Tout Puissant, Père de Notre Seigneur
Jésus-Christ, nous vous remercions de ce que vous nous avez accordé de
recevoir
votre Saint Mystère, qu’il ne soit pas pour nous une cause de
condamnation,
mais de renouvellement de l'âme, du corps et de l’esprit. Per Christum
Dominum Nostrum qui tecum vivit et regnat in unitate Spiritus Sanctus Deus,
Per Omnia Saecula
Saeculorum. Amen -
Par le même Jésus-Christ, votre Fils, notre Seigneur, qui, vit et règne
avec
vous dans l'unité du Saint-Esprit.Dans tous
les
siècles des siècles.Amen
-P: Dominus vobiscum (Le Seigneur
soit avec vous)
-F: Et cum spiritu
tuo (Et avec votre
esprit)
-P: Oremus :
-Communion
et Post-Communion :
-P: Voir propre
de la fête du jour (Missel)
-Conclusion de la Messe et Bénédiction Finale:
Le Célébrant avant de quitter la Chapelle pour la
Sacristie bénit le peuple :
-P: Dominus vobiscum.
Le
Seigneur soit avec vous.
-F: Et cum spiritu tuo.
Et
avec votre esprit.
-P: Ite Missa est -F: Deo Gratias.
Allez
la Messe est accomplie.
-P: Sit
nomen Domini benedictum.
Que le nom du Seigneur soit
béni.
-F: Ex hoc nunc et usque in sæculum
Dès
maintenant et dans tous les siècles.
-P: Adjutórium
nostrum + in nómine Dómini.
Notre
secours est + dans le nom du
Seigneur.
-F: Qui fecit caelum
et terram.
Il a fait le ciel et la terre
-P: Benedicat
vos omnipotens Deus :
Pater+, et Filius+, et Spiritus
Sanctus+. Amen
Que
Dieu tout-puissant vous bénisse : le
Père+, le Fils+ et le Saint-Esprit+. Amen
-le Célébrant fait la lecture à voix basse du
Prologue de l’Évangile de Saint Jean:
-P: Dominus vobiscum. Le Seigneur soit avec
vous.
-F: Et cum spiritu tuo. Et avec votre esprit.
-P: Initium+ sancti
Evangelii
secundum Joannem. Commencement du Saint Évangile selon Saint Jean.
P-F: Gloria tibi
Domine. Gloire
à Vous Seigneur.
In princípio erat Verbum,
et Verbum erat apud
Deum,
et Deus erat Verbum. Hoc erat in princípio apud
Deum. Omnia
per ipsum facta sunt
: et sine ipso factum
est nihil, quod factum est : in ipso vita
erat, et vita erat lux hóminum : et lux in ténebris
lucet, et ténebræ eam
non comprehendérunt.Fuit
homo missus a Deo, cui
nomen erat Ioánnes. Hic venit
in testimónium, ut testimónium
perhibéret de lúmine, ut omnes créderent per illum.
Non erat ille lux, sed ut testimónium perhibéret
de lúmine.Erat
lux vera, quæ
illúminat omnem
hóminem veniéntem
in hunc mundum.
In mundo erat, et mundus
per ipsum factus est, et mundus eum non cognóvit. In propria venit,
et
sui eum non recepérunt.Quotquot autem
recepérunt eum,
dedit eis
potestátem fílios
Dei fíeri, his,
qui crédunt in nómine
eius : qui non ex sanguínibus, neque
ex voluntáte carnis,
neque ex voluntáte
viri, sed
ex Deo nati sunt.
Et Verbum caro factum est (On se met à genoux), et habitávit
in nobis : et vídimus
glóriam eius,
glóriam
quasi Unigéniti a Patre,
plenum grátiæ et veritátis.
-P-F:Deo grátias.
Au
commencement était le Verbe, et le Verbe était en Dieu, et le Verbe
était Dieu.
Il était en Dieu au commencement. Il a tout fait et rien de ce qui
s'est fait
ne s'est fait sans Lui. En Lui était la vie et la vie était la Lumière
des
hommes et la Lumière luit dans les ténèbres et les ténèbres ne l'ont
pas
comprise. Il y eut un homme envoyé par Dieu, du nom de Jean. Il vint en
témoin
pour rendre témoignage à la Lumière afin que tous croient par lui. Il
n'était
pas la Lumière mais il vint rendre témoignage à la Lumière. Le Verbe
était la
vraie Lumière Qui éclaire tout homme venant en ce monde
.
Il était dans le monde et le monde s'est fait par Lui et le monde ne
L'a pas
connu. Il est venu chez les Siens et les Siens ne L'ont pas reçu. Mais
à tous
ceux qui L'ont reçu, Il leur a donné le pouvoir de devenir enfants de
Dieu, à
ceux qui croient en Son Nom, qui ne sont pas nés du sang, de la volonté
de la
chair et de l'homme mais de Dieu. (On se
met à genoux)
-C: ET
VERBUM CARO FACTUM EST (ET LE
VERBE S'EST FAIT CHAIR) et Il a habité parmi nous : et nous avons
vu Sa
gloire pleine de grâce et de vérité, qui est la gloire que le Fils
Unique tient
du Père.
-P-F:Deo Gratias Nous
rendons grâces à Dieu.
-Prière pour le Roy
P-F: -Oremus: Seigneur,
sauvez le Roi (N…) ! Sauvez la Gaule
! Et exaucez-nous lorsque nous vous invoquons et bénissez sa famille.
Conservez
la Maison du Bienheureux Roi Clovis et de Saint Louis vos serviteurs et
faites
que leurs enfants soient imitateurs de leurs Foi. Gloria
Patri et Filio,et
Spiritui Sancto.Sicut
erat in principio et nunc et semper et in saecula saeculorum,
Per Christum Dominum
Nostrum Amen
Gloire
au Père et au Fils,et au
Saint-Esprit.Comme il était au commencement
maintenant
et toujours, pour les siècles des siècles,Par
le
Christ Notre Seigneur Amen.
-L’Oraison des Francs de Saint Rémy (Veme
siècle) P-F: -Oremus :O Dieu
Tout-Puissant et Eternel, qui avez établi l'empire des Francs pour être
par le
monde, l'instrument de votre très divine volonté et le glaive et le
rempart de
votre Sainte Église, nous vous en prions, prévenez toujours et en tous
lieux,
par votre céleste lumière, les fils suppliants des Francs, afin qu’ils
voient
clairement ce qu'il faut faire pour établir votre règne en ce monde, et
que,
pour réaliser ce qu'ils auront vu, ils deviennent toujours plus
puissants, par
la charité et la bravoure.Per
Christum Dominum
Amen - Par le même Christ Notre
Seigneur. Amen
-Prières de
Dévotions :-l’Ave Maria -P-F: Ave Maria, gratia plena, Dominus tecum.
Benedicta tu in mulieribus, et benedictus
fructus ventris tui,
Jesus.Sancta
Maria, Mater Dei, ora pro nobis peccatoribus,
nunc, et in hora mortis nostrae. Amen.
Je vous salue Marie, pleine de
grâce, le
Seigneur est avec Vous,vous
êtes bénie
entre toutes les femmes et Jésus, le fruit de vos entrailles est béni. Sainte
Marie, Mère de Dieu, priez pour nous pauvres pécheurs maintenant et à
l'heure
de notre mort. Amen.
-INVOCATION au
Sacré Coeur de Jésus : P-F :Sacré Coeur de Jésus j’ai
Confiance en vous,Cor Jesu sacratissimum,
Miserere nobis. Trois Fois (Coeur Sacré de Jésus,Prenez
pitié de nous.)
-Tropaire à la Sainte Famille -PF: Sainte Famille de Nazareth, petite Trinité sur
la terre,Jésus, Dieu sur la terre,Marie,
épouse de l'Esprit,Joseph, ombre du Père,
Priez pour
nous, Exaucez Nous. Amen
-Tropaire des Saints Gallicans : Bienheureux Roy Clovis, Saint Louis Roy de
France et Saint Hippolyte de Rome,Saint
Irénée de Lyon et Sainte Marie-Madeleine et les Stes Maries de la Mer,
Apôtre
des Gaules, Priez pour nous, Exaucez Nous.Amen
- Prière de
Protection du Pape Léon XIII à
Saint Michel Archange :
P-F : Saint Michel Archange, défendez nous dans le
combat, contre la malice et les embûches du démon.Que
Dieu lui fasse sentir Son empire, nous vous en supplions et vous,
Prince de la
milice céleste, repoussez en enfer par la force divine Satan et les
autres
esprits mauvais, qui œuvrent dans le monde à la perte des âmes. Amen.
- SALVE REGINA
-P-F:Salve Regina, Mater misericordiae.
Vita, dulcedo, et spes
nostra, salve.Ad te clamamus
exsules filii
Hevae.Ad
te suspiramus, gementes
et flentes in hac
lacrimarum valle.Eia
ergo, Advocata nostra,
illos tuos
misericordes oculos ad nos converte.Et
Jesum, benedictum
fructum ventris
tui, nobis
post hoc exsilium ostende.O
clemens,O pia,O
dulcis Virgo
Maria. Amen
-P: Ora pro nobis, sancta Dei Genitrix
-F: Ut digni efficiamur promissionibus Christi. Amen
Salut
Reine, Mère de miséricorde ; notre vie, notre douceur et notre
espérance, salut.Vers
vous, nous crions,
enfants d'Eve exilés.Vers vous, nous
soupirons,
gémissant et pleurant dans cette vallée de larmes.O
vous, notre avocate, tournez vers nous vos regards miséricordieux.
Et après cet exil, montrez-nous Jésus, le fruit béni de vos entrailles,Ô clémente,Ô
miséricordieuse,Ô
douce Vierge Marie . Amen
-P:Priez pour nous Sainte Mère de Dieu,
-F: Pour que
nous soyons rendus dignes
des promesses de Jésus Christ. Amen
- Prière de Vénération d’une Sainte Relique et
d’une Icône : Le
Célébrant présente la Sainte Relique et la Sainte
Icône à la Vénération de l’Assemblée et s’incline, la vénère et
l’encense
-P
: -Oremus : Nous
Vous prions, Seigneur, par les mérites de vos Saints
dont nous vénérons ici les Reliques et les Icônes de vos Saints de
daignez nous
pardonner tous nos péchés et de nous accorder la protection,et la santé de l'âme et du
corps. Per Christum Dominum
Nostrum. Amen
-Le Célébrant récite la Prière pour les Âmes du
Purgatoire et Asperge le bénitier à l’entrée de l’Oratoire trois fois
d’eau
Bénite
-P: Pie
Jesu, Domine, dona eis requiem.Dona eis requiem sempiternam+++
Amen -
Pieux
Jésus, Seigneur, donne-leur le repos.Donne-leur
le repos éternel.+++ Amen
-Sacrement Gallican de l’Onction de Guérison
-P le Célébrant
oint le front
des fidèle avec l’Huile Sainte puis leurs impose les mains :
Recevez la bénédiction de Notre Seigneur Jésus-Christ,
qu’Il vous accorde protection et santé, qu’il vous exorcise de tout
mal, au nom
de la Trinité Sainte et Éternelle : In Nomine Patris+
et Filii+ Et Spiritus
Sancti+.Amen - Au
Nom du Père+, le Fils+ et le Saint-Esprit+. Amen.
-Procession de fin, on sonne trois fois les
cloches et on déclenche la musique d’orgue ou les chants grégoriens.On
entonne trois fois les Louanges Royales : Christus vincit,Christus regnat,Christus imperat.Amen
- Le Christ vainc,
le Christ règne, le Christ gouverne ! Amen